==> openGion_dev_5.8.1.1.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE58S.sql <==
/****************************************************************************/
/* GE58 ( RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2014/08/09 15:23:13                                            */
/****************************************************************************/
CREATE TABLE GE58 (
   SYSTEM_ID    varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID       varchar (  10 )                 NOT NULL            /*  20 帳票ID   */
 , CLM          varchar (  30 )                 NOT NULL            /*  30 項目     */
 , KBOUT        varchar (   1 )                 NOT NULL            /*  40 出力区分 */
 , DATA1        varchar ( 100 )                                     /*  50 ﾃﾞｰﾀ1    */
 , DATA2        varchar (  10 )                                     /*  60 ﾃﾞｰﾀ2    */
 , DATA3        varchar (  10 )                                     /*  70 ﾃﾞｰﾀ3    */
 , DATA4        varchar (  10 )                                     /*  80 ﾃﾞｰﾀ4    */
 , DATA5        varchar (  10 )                                     /*  90 ﾃﾞｰﾀ5    */
 , DATA6        varchar (  10 )                                     /* 100 ﾃﾞｰﾀ6    */
 , DATA7        varchar (  10 )                                     /* 110 ﾃﾞｰﾀ7    */
 , DATA8        varchar (  10 )                                     /* 120 ﾃﾞｰﾀ8    */
 , DATA9        varchar (  10 )                                     /* 130 ﾃﾞｰﾀ9    */
 , DATA10       varchar (  10 )                                     /* 140 ﾃﾞｰﾀ10   */
 , DATA11       varchar (  10 )                                     /* 150 ﾃﾞｰﾀ11   */
 , DATA12       varchar (  10 )                                     /* 160 ﾃﾞｰﾀ12   */
 , DATA13       varchar (  10 )                                     /* 170 ﾃﾞｰﾀ13   */
 , DATA14       varchar (  10 )                                     /* 180 ﾃﾞｰﾀ14   */
 , DATA15       varchar (  10 )                                     /* 190 ﾃﾞｰﾀ15   */
 , FGJ          varchar (   1 )     DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar (  14 )                                     /* 820 登録日時 */
 , PGSET        varchar (  10 )                                     /* 830 作成PG   */
 , PGPSET       varchar (  10 )                                     /* 840 作成親PG */
 , USRSET       varchar (  10 )                                     /* 850 作成社員 */
 , DYUPD        varchar (  14 )                                     /* 860 更新日時 */
 , PGUPD        varchar (  10 )                                     /* 870 更新PG   */
 , PGPUPD       varchar (  10 )                                     /* 880 更新親PG */
 , USRUPD       varchar (  10 )                                     /* 890 更新者   */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE58S.sql <==
/****************************************************************************/
/* GE58 ( RFIDﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2017/04/07 09:50:28                                            */
/****************************************************************************/
CREATE TABLE GE58 (
   SYSTEM_ID    varchar (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID       varchar (  10 )                 NOT NULL            /*  20 帳票ID   */
 , CLM          varchar (  30 )                 NOT NULL            /*  30 項目     */
 , KBOUT        varchar (   1 )                 NOT NULL            /*  40 出力区分 */
 , DATA1        varchar ( 100 )                                     /*  50 ﾃﾞｰﾀ1    */
 , DATA2        varchar (  10 )                                     /*  60 ﾃﾞｰﾀ2    */
 , DATA3        varchar (  10 )                                     /*  70 ﾃﾞｰﾀ3    */
 , DATA4        varchar (  10 )                                     /*  80 ﾃﾞｰﾀ4    */
 , DATA5        varchar (  10 )                                     /*  90 ﾃﾞｰﾀ5    */
 , DATA6        varchar (  10 )                                     /* 100 ﾃﾞｰﾀ6    */
 , DATA7        varchar (  10 )                                     /* 110 ﾃﾞｰﾀ7    */
 , DATA8        varchar (  10 )                                     /* 120 ﾃﾞｰﾀ8    */
 , DATA9        varchar (  10 )                                     /* 130 ﾃﾞｰﾀ9    */
 , DATA10       varchar (  10 )                                     /* 140 ﾃﾞｰﾀ10   */
 , DATA11       varchar (  10 )                                     /* 150 ﾃﾞｰﾀ11   */
 , DATA12       varchar (  10 )                                     /* 160 ﾃﾞｰﾀ12   */
 , DATA13       varchar (  10 )                                     /* 170 ﾃﾞｰﾀ13   */
 , DATA14       varchar (  10 )                                     /* 180 ﾃﾞｰﾀ14   */
 , DATA15       varchar (  10 )                                     /* 190 ﾃﾞｰﾀ15   */
 , FGJ          varchar (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar (  14 )                                     /* 820 登録日時 */
 , PGSET        varchar (  10 )                                     /* 830 作成PG   */
 , PGPSET       varchar (  10 )                                     /* 840 作成親PG */
 , USRSET       varchar (  10 )                                     /* 850 作成社員 */
 , DYUPD        varchar (  14 )                                     /* 860 更新日時 */
 , PGUPD        varchar (  10 )                                     /* 870 更新PG   */
 , PGPUPD       varchar (  10 )                                     /* 880 更新親PG */
 , USRUPD       varchar (  10 )                                     /* 890 更新者   */
);
